CA11_Cl03.html
open | /cms/logout/ |
open | /admin/ |
type | id_username | admin
type | id_password | admin
clickAndWait | //input[@value='Iniciar sesión'] |
clickAndWait | link=Users |
clickAndWait | link=Añadir usuario |
clickAndWait | _save |
verifyTextPresent | Este campo es obligatorio. |
verifyTextPresent | exact:Usuario: |
verifyTextPresent | Este campo es obligatorio. |
verifyTextPresent | Contraseña: |
verifyTextPresent | Este campo es obligatorio. |
verifyTextPresent | Contraseña (de nuevo): |
clickAndWait | link=Terminar sesión |